@@ -1,13 +1,13 @@
 #!/bin/bash
 
-source $MOD_GIT_ROOTDIR/doc/example/compiler-etc-dependencies/example-sessions/common_code.sh
+source "$MOD_GIT_ROOTDIR"/doc/example/compiler-etc-dependencies/example-sessions/common_code.sh
 
 do_cmd module purge
 do_cmd module load pgi/19.4
 do_cmd module load openmpi
 do_cmd module list
 do_cmd mpirun
-do_cmd module switch $AUTOFLAG pgi intel/2019
+do_cmd module switch "$AUTOFLAG" pgi intel/2019
 do_cmd module list
 do_cmd mpirun
 case $TMP_STRATEGY in
@@ -16,7 +16,7 @@ case $TMP_STRATEGY in
 	case $TMP_MODVERSION in
            3.*)
 		#Only do it on 3.x, as switch fails on 4.x
-		do_cmd module switch $AUTOFLAG intel intel/2018
+		do_cmd module switch "$AUTOFLAG" intel intel/2018
 		do_cmd module list
 		do_cmd mpirun
 		;;
@@ -27,7 +27,7 @@ case $TMP_STRATEGY in
 	case $TMP_MODVERSION in
            4.*)
 		#Only do it on 4.x, as switch fails on 3.x
-		do_cmd module switch $AUTOFLAG intel intel/2018
+		do_cmd module switch "$AUTOFLAG" intel intel/2018
 		do_cmd module list
 		do_cmd mpirun
 		;;
